<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>Režim lietadlo zapnutý</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>Režim lietadlo vypnutý</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Vypnúť</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Zapnúť</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Režim lietadlo</translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Režim lietadlo</translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Nastavenia bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Vypnuté</translation>
    </message>
    <message>
        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Vypnúť</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Zapnúť</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Nastavenia bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 pripojené</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Pripájanie sa...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Vypnuté</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>Pripojené  %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nepripojené</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Vypnuté</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation>Jas</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Nastavenie obrazovky</translation>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation>Nastavenie obrazovky</translation>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation>Jas</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>Ne</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>Po</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>Ut</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>St</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>Št</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>Pia</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>So</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Pridať rozloženie klávesnice</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Dátum Čas</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12-hodinový čas</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24-hodinový čas</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Nastavenia času</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>Pondelok</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Utorok</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Streda</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Štvrtok</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Piatok</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sobota</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Nedeľa</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>pondelok</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>Utorok</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>streda</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>štvrtok</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>piatok</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>sobota</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>nedeľa</translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Vypnúť</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Zapnúť</translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation type="unfinished">Nastavenie obrazovky</translation>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Off</source>
        <translation type="unfinished">Vypnuté</translation>
    </message>
    <message>
        <source>Light</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Visual effect</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notification settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notification</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Onboard</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavenia</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Balanced</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Power Saver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation>Nastavenia napájania</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Nabíjanie %1, zostávajú %2 min</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Nabíjanie %1, zostáva %2 hod %3 min</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Nabíjanie %1, %2 min do plnej kapacity</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Nabíjanie %1, %2 hod %3 min do plnej kapacity</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Kapacita %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Nabíjanie %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Kapacita %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Kapacita %1, plne nabité</translation>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Battery</source>
        <translation>Batéria</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not charging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fully charged</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation type="unfinished">Nastavenia napájania</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>Vypnúť</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Uspať</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernácia</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zamknúť</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Odhlásiť</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Nastavenia napájania</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reštart</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>y</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>m</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>d</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Monday</source>
        <translation type="unfinished">Pondelok</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation type="unfinished">Utorok</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation type="unfinished">Streda</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation type="unfinished">Štvrtok</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation type="unfinished">Piatok</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation type="unfinished">Sobota</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation type="unfinished">Nedeľa</translation>
    </message>
    <message>
        <source>Jan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Feb</source>
        <translation>Feb</translation>
    </message>
    <message>
        <source>Mar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Apr</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>May</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Jun</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Jul</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aug</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sept</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Oct</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nov</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>monday</source>
        <translation type="unfinished">pondelok</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation type="unfinished">Utorok</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation type="unfinished">streda</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation type="unfinished">štvrtok</translation>
    </message>
    <message>
        <source>friday</source>
        <translation type="unfinished">piatok</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation type="unfinished">sobota</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation type="unfinished">nedeľa</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>Hlasitosť</translation>
    </message>
    <message>
        <source>Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Zvuk</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
